<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-07-21 03:49:58+0000','plural-forms'=>'nplurals=6; plural=(n == 0) ? 0 : ((n == 1) ? 1 : ((n == 2) ? 2 : ((n % 100 >= 3 && n % 100 <= 10) ? 3 : ((n % 100 >= 11 && n % 100 <= 99) ? 4 : 5))));','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'ar','messages'=>['Editor NameClassic Editor'=>'Classic Editor المحرر التقليدي','Editor NameBlock editor'=>'مُحرر المكوّنات','Editor NameClassic editor'=>'Classic Editor المحرر التقليدي','Editor NameEdit (classic editor)'=>'تحرير (المحرر التقليدي)','Editor NameEdit (block editor)'=>'تحرير (مُحرر المكوّنات)','Change settings'=>'تغيير الإعدادات','Default editor for all sites'=>'المحرر الافتراضي لجميع المواقع','Editor Settings'=>'إعدادات المحرر','Default Editor'=>'المحرر الافتراضي','Editor Nameblock editor'=>'مُحرر المكوّنات','Editor Nameclassic editor'=>'المحرر التقليدي','Edit &#8220;%s&#8221; in the block editor'=>'تحرير &#8220;%s&#8221; في مُحرر المكوّنات','Switch to block editor'=>'التبديل إلى مُحرر المكوّنات','Switch to classic editor'=>'التبديل إلى المحرر التقليدي','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'بشكل افتراضي، يتمّ استبدال مُحرر المكوّنات بالمحرر التقليدي ولا يمكن للمستخدمين التبديل بين المُحررين.','Allow site admins to change settings'=>'السماح لمدراء الموقع بتغيير الإعدادات','Editor'=>'المُحرر','No'=>'لا','Yes'=>'نعم','Allow users to switch editors'=>'السماح للمستخدمين للتبديل بين المُحررين','Default editor for all users'=>'المُحرر الافتراضي لجميع المستخدمين','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'مساهمو ووردبريس','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'لتمكين مُحرّر ووردبريس التقليدي والنمط القديم لمظهر وتنسيق شاشة المقالة مع محرر TinyMCE، حقول الميتا التعريفية المخصصة، الخ. تدعم هذه الإضافة تلك الإضافات التي تعززها هذه الشاشة.','Classic Editor'=>'Classic Editor المحرر التقليدي','Edit &#8220;%s&#8221; in the classic editor'=>'تحرير &#8220;%s&#8221; في المحرر التقليدي','Settings'=>'الإعدادات']];